@@ -3,9 +3,13 @@ from rest_framework import authentication
 from django.contrib.auth.models import User
 from django.conf import settings
 from rest_framework import exceptions
+import logging
 import requests
 
 
+logger = logging.getLogger(__name__)
+
+
 class IdentityAuthentication(authentication.BaseAuthentication):
     """
     This should be the first authentication that user goess through, since we always trust the local sessions
@@ -50,7 +54,9 @@ class IdentitySSOAuthentication(authentication.BaseAuthentication):
                 e.response.status_code,
                 e.response.content,
             )
-            raise exceptions.AuthenticationFailed(message)
+            logger.warning(message)
+            return None
+
         user_info = user_info_reply.json()
         email = user_info["user"]["email"]
         user, _ = User.objects.get_or_create(
