@@ -31,8 +31,9 @@ def include_internal_urls():
 @authentication_classes([])
 def login(request):
     auth_redirect_url: str = request.build_absolute_uri().split("?")[0]
-    # since the app is running in container, no way to know its on ssl
-    auth_redirect_url = auth_redirect_url.replace("http", "https")
+    # since the app is running in container, it might mistakenly
+    # assume it's not using SSL/TLS
+    auth_redirect_url = auth_redirect_url.replace("http:", "https:")
     auth_code: str = request.query_params.get("code", "")
     app_redirect_url: str = request.query_params.get("state", "")
 
@@ -148,4 +149,4 @@ def delete_all_unexpired_sessions_for_user(user):
     logger.debug(f"found {len(user_sessions)} user sessions")
     count, sessions_deleted = Session.objects.filter(pk__in=user_sessions).delete()
     logger.debug(count)
-    logger.debug(sessions_deleted)
\ No newline at end of file
+    logger.debug(sessions_deleted)
